/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.util.Properties;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author Michael Hashimoto
 */
public abstract class BaseJob implements Job {

	@Override
	public String getJobName() {
		return jobName;
	}

	protected BaseJob(String jobName) {
		this.jobName = jobName;
	}

	protected String getProperty(Properties properties, String name) {
		if (!properties.containsKey(name)) {
			return null;
		}

		String value = properties.getProperty(name);

		Matcher matcher = _propertiesPattern.matcher(value);

		String newValue = value;

		while (matcher.find()) {
			newValue = newValue.replace(
				matcher.group(0), getProperty(properties, matcher.group(1)));
		}

		return newValue;
	}

	protected String jobName;

	private static final Pattern _propertiesPattern = Pattern.compile(
		"\\$\\{([^\\}]+)\\}");

}